***Burke: Economic Growth and Political Survival. B.E. Journal of Macroeconomics. 
***Feel free to contact me if you have any questions
# delimit;
version 9.2;
clear;
capture log using Burke.log, replace;
set more off;
set matsize 2000;
set memory 200m;
use C:\Burke_BEMacro\Burke.dta;
sort code year;
tsset ccodewb year;
set emptycells drop;

******************************************************************************************************
*VARIABLE CONSTRUCTION;
******************************************************************************************************
*Archigos variable construction;
	gen yearstartish = date(startdate,"dmy");
	gen startyear = yofd(yearstartish);
	gen tenure=year-startyear;
	gen regulardummy=0 if year>=startyear;
	replace regulardummy=1 if exit_tv==1;
	gen irregulardummy=0 & year>=startyear;
	replace irregulardummy=1 if exit_tv==3; 
		
	*There are cases in which there was a second leader exit in a year in which the first leader exit was due to natural death. It is resolved to include these as leader exits (results are similar either way). The following code does this;
		replace regulardummy=1 if code=="VNM" & year==1986; 
		replace regulardummy=1 if code=="ESP" & year==1975;
		replace regulardummy=1 if code=="FRA" & year==1974;
		replace regulardummy=1 if code=="GUY" & year==1997;
		replace regulardummy=1 if code=="IND" & year==1964;
		replace regulardummy=1 if code=="IND" & year==1966;
		replace regulardummy=1 if code=="IRN" & year==1989;
		replace regulardummy=1 if code=="ISR" & year==1969;
		replace regulardummy=1 if code=="JPN" & year==1980;
		replace irregulardummy=1 if code=="BOL" & year==1969;
		replace irregulardummy=1 if code=="GIN" & year==1984;
			
	generate sickdummy=0 & year>=startyear;
	replace sickdummy=1 if exit_tv>2.05 & exit_tv<2.15;
	replace regulardummy=1 if exit_tv>2.05 & exit_tv<2.25;
	generate deathdummy=0 & year>=startyear;
	replace deathdummy=1 if exit_tv>1.9 & exit_tv<2.01;;
	generate leaderchangedummy=0 & year>=startyear;
	replace leaderchangedummy=1 if exit_tv>0.9 & exit_tv<4.1 ;
	generate dummy=regulardummy+irregulardummy;
	generate nonsickdummy=dummy-sickdummy;
	gen leaderchangesum=numld-1;
	generate entrydummy=0;
	replace entrydummy=1 if entry==1;
	replace entrydummy=1 if entry==2;	
	
	*The below is to code leader exits which occured on last day of year;
		replace leaderchangesum=1 if code=="CHE";
		replace leaderchangesum=1 if code=="BRA" & year==1994;
		replace leaderchangesum=1 if code=="RUS" & year==1999;
		replace leaderchangesum=1 if code=="SEN" & year==1980;
		
	*There are 3 cases in which there was a second leader exit in a year in which the first leader exit was due to sickness. It is resolved to include these as leader exits for the nonsickdummy robustness check (results are similar either way). The following code does this;
		replace nonsickdummy=1 if code=="BRA" & year==1969;
		replace nonsickdummy=1 if code=="JPN" & year==2000;
		replace nonsickdummy=1 if code=="NOR" & year==1981;
			
*Merging original Archigos with 2005-2006 author-coded data to allow estimation for extended sample to 2006;
	replace startyear=startyear_n if startyear_n~=. & year>2004;
	replace dummy=dummy_n if dummy_n~=. & year>2004;
	replace tenure=tenure_n if tenure_n~=. & year>2004;
	replace age=age_n if age_n~=. & year>2004;
	replace prevtimesinoffice=prevtimesinoffice_n if prevtimesinoffice_n~=. & year>2004;
	replace entrydummy=entrydummy_n if entrydummy_n~=. & year>2004;
	replace regulardummy=regulardummy_n if regulardummy_n~=. & year>2004;
	replace irregulardummy=irregulardummy_n if irregulardummy_n~=. & year>2004;
	replace sickdummy=sickdummy_n if sickdummy_n~=. & year>2004;
	replace deathdummy=deathdummy_n if deathdummy_n~=. & year>2004;
	replace leaderchangesum=leaderchangesum_n if leaderchangedummy_n~=. & year>2004;
	replace leaderchangedummy=leaderchangedummy_n if leaderchangedummy_n~=. & year>2004;
	replace exit_tv=exit_tv_n if leaderchangedummy_n~=. & year>2004;
	replace nonsickdummy=nonsickdummy_n if nonsickdummy_n~=. & year>2004;
	replace gender=gender_n if gender_n~=. & year>2004;
	replace leader=leader_n if gender_n~=. & year>2004;
	generate nondeathdummy=dummy;
	replace nondeathdummy=0 if deathdummy==1 & dummy==1;
	replace nondeathdummy=0 if deathdummy_n==1 & dummy==1;
		
*Weather instruments;
	generate cold=0 if averagetemperature19601970~=.;
	replace cold=1 if averagetemperature19601970<12;
	generate wpre_100=wpre*100;
	generate prec=wpre_100;
	replace prec=precipitation if code=="SGP" | code=="MLT" | code=="BHR" | code=="BRB" | code=="MDV";
	generate lnprec=ln(prec);
	generate temp_comb=wtem;
	replace temp_comb=temperature if code=="SGP" | code=="MLT" | code=="BHR" | code=="BRB" | code=="MDV";
	gen temp_comb_cold=temp_comb*cold;
	gen ins_cp=dlogpriceindexinteracted_95/100;
	gen ins_epg=exportpartnergrowthwdiint_95/100;
	gen ins_pre=lnprec/100;
	gen ins_tem1=temp_comb/100;
	gen ins_tem2=temp_comb_cold/100;

*Constructing enrolment rate and infant mortality rate variables;
	generate grosssecondcombined=grosssecond if year>1996;
	replace grosssecondcombined=grossseconddri if year<1997;
	by ccodewb: ipolate grosssecondcombined year, generate(grosssecondcombinedinter);
	by ccodewb: ipolate imr year, generate(imrinter);
	generate yearreverse=-1*year;
	generate grosssecondcombinedextra=grosssecondcombinedinter;
	xi: replace grosssecondcombinedextra=l.grosssecondcombinedextra if grosssecondcombinedextra==.;
	sort ccodewb yearreverse;
	tsset ccodewb yearreverse;
	xi: replace grosssecondcombinedextra=l.grosssecondcombinedextra if grosssecondcombinedextra==.;
	xi: replace imrinter=l.imrinter if imrinter==.;
	generate lnimrinter=ln(imrinter);
	sort code year;
	tsset ccodewb year;
		
*Cheibub democracy dummy;
	generate demcheib=democracy_cheibub;
	replace demcheib=0 if democracy_cheibub==.; *If a country isn't independent or isn't clearly classed as a democracy, it is counted as an autocracy. This involves few observations (and only early ones). Does not affect overall results;
	xi: generate ldemcheib=l.demcheib;

*Other;
	generate gdppthous=gdpp/1000;
	generate transitionperiod=0;
	replace transitionperiod=1 if transition==1 & year>1988 & year<1993;
	generate lnpopulation=ln(population);
	replace sanctions=0 if code=="LUX";
	generate conflict=0 if ucdp_type3~=.;
	replace conflict=1 if ucdp_type3~=. & ucdp_type3>0;	
	replace conflict=1 if ucdp_type4~=. & ucdp_type4>0;	*this allows internationalised internal conflicts e.g. DRC to be included;
	gen lngdpp=ln(gdpp);
	gen lnrgdpch=ln(rgdpch);
	gen lnrgdptt=ln(rgdptt);

	replace year_firstarchigos=l.year_firstarchigos if year_firstarchigos==.;
	replace year_firstarchigos=l.year_firstarchigos if year_firstarchigos==.;
	generate firstleaderdummy=0 if regulardummy~=.;
	replace firstleaderdummy=1 if startyear==year_firstarchigos;
	
	generate domestic5dummy=0 if domestic5~=.;
	replace domestic5dummy=1 if domestic5>0 & domestic5~=.;
	
	gen ag_vashare_95_1=agriculture_va_95/total_va_95*100;		
	bysort code: egen ag_vashare_95=max(ag_vashare_95_1);
		
*Lags;
	sort code year;
	tsset ccodewb year;
	xi: generate ldemocracy_boix=l.democracy_boix;
	xi: generate laggrowthpercapita=l.growthpercapita;
	xi: gen fgrowthpercapita=f.growthpercapita;
	xi: generate lag2growthpercapita=l2.growthpercapita;
	xi: generate lag3growthpercapita=l3.growthpercapita;
	xi: generate grgdpch=(rgdpch-l.rgdpch)/l.rgdpch*100;
	xi: generate lgrgdpch=l.grgdpch;
	xi: generate grgdptt=(rgdptt-l.rgdptt)/l.rgdptt*100;
	xi: generate lgrgdptt=l.grgdptt;
	xi: generate laggdpgrowth=l.gdpgrowth;
	xi: generate l2grosssecondcombinedextra=L2.grosssecondcombinedextra;
	generate l2g=l2grosssecondcombinedextra;
	xi: generate l2old=l2.old;
	xi: generate l2urban=l2.urban;
	xi: generate l2imrinter=l2.imrinter;
	xi: generate l2exports=l2.exports;
	xi: generate l2youth=l2.youth;
	xi: gen l2lngdpp=l2.lngdpp;
	xi: gen l2gdpp=l2.gdpp;
	xi: gen l2lnrgdpch=l2.lnrgdpch;
	xi: generate lsanctions=l.sanctions;
	generate l2lnpopulation=l2.lnpopulation;
	xi: generate lconflict=l.conflict;
		
*Cheibub leader exit variable;
	generate dummysumpr=eheads;
	generate dummych=0 if eheads~=.;
	replace dummych=1 if eheads>0 & eheads~=.;
	replace dummych=0 if l.edeath==0 & eheads~=.;

*Databanks leader exit variable;
	generate dummybanks=polit12;
	replace dummybanks=1 if polit12>1 & polit12~=.;		

*OPEC;
	gen opec=0;
	replace opec=1 if code=="DZA";
	replace opec=1 if code=="AGO";
	replace opec=1 if code=="ECU";
	replace opec=1 if code=="IRN";
	replace opec=1 if code=="IRQ";
	replace opec=1 if code=="KWT";
	replace opec=1 if code=="LBY";
	replace opec=1 if code=="NGA";
	replace opec=1 if code=="QAT";
	replace opec=1 if code=="SAU";
	replace opec=1 if code=="ARE";
	replace opec=1 if code=="VEN";

*Largest 20 economies in 1995 based on GDP in USD (WDI);
	gen largest20country=0;
	replace largest20country=1 if code=="USA";
	replace largest20country=1 if code=="JPN";
	replace largest20country=1 if code=="DEU";
	replace largest20country=1 if code=="GBR";
	replace largest20country=1 if code=="FRA";
	replace largest20country=1 if code=="ITA";
	replace largest20country=1 if code=="CHN";
	replace largest20country=1 if code=="CAN";
	replace largest20country=1 if code=="BRA";
	replace largest20country=1 if code=="ESP";
	replace largest20country=1 if code=="MEX";
	replace largest20country=1 if code=="KOR";
	replace largest20country=1 if code=="IND";
	replace largest20country=1 if code=="AUS";
	replace largest20country=1 if code=="NLD";
	replace largest20country=1 if code=="ARG";
	replace largest20country=1 if code=="RUS";
	replace largest20country=1 if code=="CHE";
	replace largest20country=1 if code=="TUR";
	replace largest20country=1 if code=="SWE";
				
*Setting sample size;
	xi: xtreg dummy L.growthpercapita L2.lngdpp i.year if code~="SAU" & code~="TMP" & code~="IRQ" & year>1961 & l.lnprec~=. & l2.lnprec~=., fe cluster(ccodewb); *This is new sample, but needs to be reduced due to some missing weather data. SAU excluded due to influence over oil price. TMP excluded due to no 1995. Iraq excluded due to war effect for small number of years for which GDP growth data available;
	generate sample_act=1 if e(sample);
	by ccodewb: egen avl2gdpp=mean(l2gdpp) if sample_act==1;	
		
*Elections variable;
	generate yearparl=date(parldate1,"mdy");
	gen yearparl1=yofd(yearparl);
	generate yearprez=date(prezdate1, "mdy");
	gen yearprez1=yofd(yearprez);
	generate electionflagparl=.;
	replace electionflagparl=1 if yearparl1~=.;
	generate electionflagpres=.;
	replace electionflagpres=1 if yearprez1~=.;
	generate electionflagtotal=1 if electionflagparl==1;
	replace electionflagtotal=1 if electionflagpres==1;
	replace electionflagtotal=0 if electionflagtotal==.;
	replace electionflagpres=0 if electionflagpres==.;
	replace electionflagparl=0 if electionflagparl==.;
	generate presidentialflag=0 if systemarchigos~=.;
	generate assemblypresidentialflag=0 if systemarchigos~=.;
	generate parliamentaryflag=0 if systemarchigos~=.;
	replace presidentialflag=1 if systemarchigos==0;
	replace assemblypresidentialflag=1 if systemarchigos==1;
	replace parliamentaryflag=1 if systemarchigos==2;
	generate electionconstructed=presidentialflag*electionflagpres+electionflagparl*parliamentaryflag+assemblypresidentialflag*electionflagtotal;
	xi: generate lelectionconstructed=presidentialflag*l.electionflagpres+l.electionflagparl*parliamentaryflag+assemblypresidentialflag*l.electionflagtotal if sample_act==1; *This operation ensures that only elections affecting the leader at the start of year t are counted, given the leader status (PM/president) of the leader at the start of year t. An alternative way to construct a similar variable would be to just take the lag of the election dummy. Results are similar either way;
		
******************************************************************************************************
*RESULTS;
******************************************************************************************************

*Figure 1;
	summ f2.growthpercapita f.growthpercapita growthpercapita l.growthpercapita l2.growthpercapita l3.growthpercapita l4.growthpercapita l5.growthpercapita if sample_act==1 & dummy==1;
	summ laggrowthpercapita if sample_act==1;
	*These data are used in Figure 1;

*Table 1;
	xi: summ L.growthpercapita L2.gdppthous l2.grosssecondcombinedextra l2.old tenure age transitionperiod l.demcheib electionconstructed termlimitflag domestic5dummy l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb if sample_act==1;
	codebook dummy if sample_act==1;
	summ leaderchangesum if sample_act==1 & l.demcheib==1;
	summ leaderchangesum if sample_act==1 & l.demcheib==0;

*Table 2;
	*LPM;
		xi: xtreg dummy laggrowthpercapita i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtreg dummy laggrowthpercapita l2lngdpp l2grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year if sample_act==1, fe cluster(ccodewb);

	*Logit;
		xi: clogit dummy laggrowthpercapita i.year if sample_act==1, group(ccodewb) cluster(ccodewb) or;
		generate sample_logit=1 if e(sample);
		xi: clogit dummy laggrowthpercapita l2lngdpp l2grosssecondcombinedextra l2old tenure age transitionperiod ldemcheib electionconstructed lelectionconstructed termlimitflag i.year if sample_act==1, group(ccodewb) cluster(ccodewb) or;
		xi: xtreg dummy L.growthpercapita i.year if e(sample), fe cluster(ccodewb);
		xi: xtreg dummy L.growthpercapita L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year if e(sample), fe cluster(ccodewb);
		codebook dummy if e(sample);
	
	*Hazard model set up;
		generate startyear_st=startyear;
		replace startyear_st=startyear-1 if year==startyear & sample_act==1; *This ensures that cases where leader entered on 1 January are still included in hazards estimation;
		egen leadidnew=concat(leader code startyear);
		stset year, failure(nondeathdummy) id(leadidnew) origin(time startyear_st); 
	
	*Hazard model regressions;
		xi: stcox laggrowthpercapita i.year i.ccodewb if sample_act==1, vce(cluster ccodewb);
		xi: stcox laggrowthpercapita l2lngdpp l2grosssecondcombinedextra l2old tenure age transitionperiod ldemcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb if sample_act==1, vce(cluster ccodewb);
		
*Table 3 - reduced form estimates;
	*Instruments have been divided by 100 to avoid needing to show too many decimal places;
		xi: xtreg dummy l.ins_cp l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2 i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtreg dummy l.ins_cp l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2 L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year if sample_act==1, fe cluster(ccodewb);

	*Im-Pesaran-Shin unit root tests;
		bysort ccode: egen tester=count(laggrowthpercapita) if sample_act==1;
		gen logpriceindex_95=ln(priceindexarith_95);
		xtunitroot ips logpriceindex_95 if sample_act==1 & tester>9;
		xtunitroot ips priceindexarith_95 if sample_act==1 & tester>9;
		xtunitroot ips l2gdpp if sample_act==1 & tester>9;
		xtunitroot ips l2lngdpp if sample_act==1 & tester>9;
		xtunitroot ips laggrowthpercapita if sample_act==1 & tester>9;
		xtunitroot ips lnprec if sample_act==1 & tester>9;
		xtunitroot ips prec if sample_act==1 & tester>9;
		xtunitroot ips temp_comb if sample_act==1 & tester>9;
	
	*Fisher test provides similar results, e.g.;
		xtunitroot fisher laggrowthpercapita if sample_act==1 & tester>9, dfuller lags(1);
		xtunitroot fisher lnprec if sample_act==1 & tester>9, dfuller lags(1);
		xtunitroot fisher temp_comb if sample_act==1 & tester>9, dfuller lags(1);
		sort code year;
		tsset ccodewb year;	

*Table 4;
	xi: xtreg dummy laggrowthpercapita i.year if sample_act==1, fe cluster(ccodewb);
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Testing for endogeneity and overidentification;
		*Tests only work if robust standard errors and 2sls;
		xi: ivregress 2sls dummy i.year i.ccodewb (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, robust;
		estat endogenous; *The test is rejected if p value less than 0.1 - this would mean economic growth must be treated as endogenous;
		estat overid; *This means that the instruments are not rejected as invalid: "A statistically significant test statistic always indicates that the instruments may not be valid.";
		xi: ivregress 2sls dummy i.year i.ccodewb (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy i.year i.ccodewb (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy i.year i.ccodewb (laggrowthpercapita=l.lnprec) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy i.year i.ccodewb (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, robust;
		estat endogenous;

*Table 5;
	xi: xtreg dummy laggrowthpercapita L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year if sample_act==1, fe cluster(ccodewb);
	xi: xtivreg2 dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year (laggrowthpercapita=l.lnprec) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Testing for endogeneity and overidentification;
		*Tests only work if robust standard errors and 2sls;
		xi: ivregress 2sls dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, robust;
		estat endogenous; *So the test is rejected - this means economic growth must be treated as endogenous;
		estat overid; *This means that the instruments are not rejected as invalid: "A statistically significant test statistic always indicates that the instruments may not be valid.";
		xi: ivregress 2sls dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb (laggrowthpercapita=l.lnprec) if sample_act==1, robust;
		estat endogenous;
		xi: ivregress 2sls dummy L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag i.year i.ccodewb (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, robust;
		estat endogenous;

*Table 6 - Instrumenting with one instrument, putting other instruments into 2nd stage;
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.ins_cp) l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2 if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	test l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2;
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.ins_epg) l.ins_cp l.ins_pre l.ins_tem1 l.ins_tem2 if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	test l.ins_cp l.ins_pre l.ins_tem1 l.ins_tem2;
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.ins_pre) l.ins_cp l.ins_epg l.ins_tem1 l.ins_tem2 if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	test l.ins_cp l.ins_epg l.ins_tem1 l.ins_tem2;
	xi: xtivreg2 dummy i.year (laggrowthpercapita=l.ins_tem1 l.ins_tem2) l.ins_cp l.ins_epg l.ins_pre if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	test l.ins_cp l.ins_epg l.ins_pre;

*Table 7 - Dynamic specifications, and using PWT growth;	
	*WDI;
	xi: xtreg dummy laggrowthpercapita l.leaderchangedummy i.year if sample_act==1, fe cluster(ccodewb);
	xi: xtivreg2 dummy l.leaderchangedummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*PWT;
	xi: xtreg dummy lgrgdpch l.leaderchangedummy i.year if sample_act==1, fe cluster(ccodewb);
	xi: xtivreg2 dummy l.leaderchangedummy i.year (lgrgdpch=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	
	*PWT;
	xi: xtreg dummy lgrgdptt l.leaderchangedummy i.year if sample_act==1, fe cluster(ccodewb);
	xi: xtivreg2 dummy l.leaderchangedummy i.year (lgrgdptt=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	xi: xtivreg2 dummy l.leaderchangedummy i.year (lgrgdptt=l.dlogpriceindexinteracted_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);

*Table 8 - timing of the effect;
	xi: xtivreg2 dummy i.year (fgrowthpercapita=f.dlogpriceindexinteracted_95 f.exportpartnergrowthwdiint_95 f.lnprec f.temp_comb f.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	xi: xtivreg2 dummy i.year (growthpercapita=dlogpriceindexinteracted_95 exportpartnergrowthwdiint_95 lnprec temp_comb temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	xi: xtivreg2 dummy i.year (lag2growthpercapita=l2.dlogpriceindexinteracted_95 l2.exportpartnergrowthwdiint_95 l2.lnprec l2.temp_comb l2.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	xi: xtivreg2 dummy i.year (laggrowthpercapita lag2growthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l2.dlogpriceindexinteracted_95 l2.exportpartnergrowthwdiint_95 l2.lnprec l2.temp_comb l2.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	xi: xtivreg2 dummy i.year (growthpercapita laggrowthpercapita=dlogpriceindexinteracted_95 exportpartnergrowthwdiint_95 lnprec temp_comb temp_comb_cold l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);
	xi: xtivreg2 dummy i.year (fgrowthpercapita growthpercapita laggrowthpercapita lag2growthpercapita=f.dlogpriceindexinteracted_95 f.exportpartnergrowthwdiint_95 f.lnprec f.temp_comb f.temp_comb_cold dlogpriceindexinteracted_95 exportpartnergrowthwdiint_95 lnprec temp_comb temp_comb_cold l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l2.dlogpriceindexinteracted_95 l2.exportpartnergrowthwdiint_95 l2.lnprec l2.temp_comb l2.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	codebook dummy if e(sample);

*Table 9 - sub-samples;
	*Agricultural countries;
		summ ag_vashare_95 if sample_act==1, detail;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1 & ag_vashare_95>33.333333333333, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1 & ag_vashare_95>33.333333333333, first fe fuller(1) cluster(ccodewb) partial(i.year);
		codebook dummy if e(sample);

	*Poor and hot countries;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1 & avl2gdpp<600 & cold~=1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.temp_comb) if sample_act==1 & avl2gdpp<600 & cold~=1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		codebook dummy if e(sample);
	
	*SSA;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1 & region=="Sub-Saharan Africa", first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1 & region=="Sub-Saharan Africa", first fe fuller(1) cluster(ccodewb) partial(i.year);
		codebook dummy if e(sample);

*Table 10 - interactions;
	*1. Dem dummy interaction;
		generate interactdemlag=laggrowthpercapita*l.demcheib;
		xi: gen insdem1lag=dlogpriceindexinteracted_95*demcheib;
		xi: gen insdem2lag=exportpartnergrowthwdiint_95*demcheib;
		xi: gen insdem3lag=lnprec*demcheib; 
		xi: gen insdem4lag=temp_comb*demcheib;
		xi: gen insdem5lag=temp_comb_cold*demcheib; 
		
		xi: xtreg dummy laggrowthpercapita interactdemlag l.demcheib i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy l.demcheib i.year (laggrowthpercapita interactdemlag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1lag l.insdem2lag l.insdem3lag l.insdem4lag l.insdem5lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy l.demcheib i.year (laggrowthpercapita interactdemlag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.insdem1lag l.insdem2lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*2. Polity2 interaction;
		generate polity2_sc=polity2/10;
		generate interactp2lag=laggrowthpercapita*l.polity2_sc;
		xi: gen inspol1l=dlogpriceindexinteracted_95*polity2_sc;
		xi: gen inspol2l=exportpartnergrowthwdiint_95*polity2_sc;
		xi: gen inspol3l=lnprec*polity2_sc; 
		xi: gen inspol4l=temp_comb*polity2_sc;
		xi: gen inspol5l=temp_comb_cold*polity2_sc;	
	
		xi: xtreg dummy laggrowthpercapita interactp2lag l.polity2_sc i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy l.polity2_sc i.year (laggrowthpercapita interactp2lag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.inspol1l l.inspol2l l.inspol3l l.inspol4l l.inspol5l) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy l.polity2_sc i.year (laggrowthpercapita interactp2lag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.inspol1l l.inspol2l) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Boix;
		generate interactboixl=laggrowthpercapita*l.democracy_boix;
		xi: gen insdem1bl=dlogpriceindexinteracted_95*democracy_boix; *Note that this gets lagged in the IV process; 
		xi: gen insdem2bl=exportpartnergrowthwdiint_95*democracy_boix;
		xi: gen insdem3bl=lnprec*democracy_boix; 
		xi: gen insdem4bl=temp_comb*democracy_boix;
		xi: gen insdem5bl=temp_comb_cold*democracy_boix; 	
		xi: xtreg dummy laggrowthpercapita interactboixl l.democracy_boix i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy l.democracy_boix i.year (laggrowthpercapita interactboixl=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1bl l.insdem2bl l.insdem3bl l.insdem4bl l.insdem5bl) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy l.democracy_boix i.year (laggrowthpercapita interactboixl=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.insdem1bl l.insdem2bl) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Sub-samples;
	*Democracy;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1 & l.demcheib==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*Autocracy;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1 & l.demcheib==0, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*PWT;
		generate interactdemlagpwt=lgrgdpch*l.demcheib;
		xi: xtivreg2 dummy l.demcheib i.year (lgrgdpch interactdemlagpwt=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1lag l.insdem2lag l.insdem3lag l.insdem4lag l.insdem5lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

*Table 11;
	*1. LnGDPPt-2;
		generate interactgdpp=laggrowthpercapita*L2.lngdpp;	
		xi: gen insgdp1=dlogpriceindexinteracted_95*L.lngdpp;
		xi: gen insgdp2=exportpartnergrowthwdiint_95*L.lngdpp;
		xi: gen insgdp3=lnprec*L.lngdpp; 
		xi: gen insgdp4=temp_comb*L.lngdpp;
		xi: gen insgdp5=temp_comb_cold*L.lngdpp; 
	
		xi: xtreg dummy laggrowthpercapita interactgdpp L2.lngdpp i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy L2.lngdpp i.year (laggrowthpercapita interactgdpp=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insgdp1 l.insgdp2 l.insgdp3 l.insgdp4 l.insgdp5) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy L2.lngdpp i.year (laggrowthpercapita interactgdpp=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.insgdp1 l.insgdp2) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*2. Dell style poor dummy;
		bysort year: egen lngdpp_median=median(lngdpp) if sample_act==1;
		bysort code: egen firstyear_sample_act_1=min(year) if sample_act==1;	
		sort code year;
		generate poor_dell_1=0 if sample_act==1;
		replace poor_dell_1=1 if sample_act==1 & firstyear_sample_act_1==year & lngdpp<lngdpp_median;
		by code: egen poor_dell=max(poor_dell_1) if sample_act==1;
		sort code year;
		tsset ccodewb year;
		generate interactpoor_dell=laggrowthpercapita*poor_dell;
		xi: gen insdell1=dlogpriceindexinteracted_95*f.poor_dell; *Note that this gets lagged in the IV process, and is constant for all countries; 
		xi: gen insdell2=exportpartnergrowthwdiint_95*f.poor_dell;
		xi: gen insdell3=lnprec*f.poor_dell; 
		xi: gen insdell4=temp_comb*f.poor_dell;
		xi: gen insdell5=temp_comb_cold*f.poor_dell; 	
	
		xi: xtreg dummy laggrowthpercapita interactpoor_dell i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy i.year (laggrowthpercapita interactpoor_dell=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdell1 l.insdell2 l.insdell3 l.insdell4 l.insdell5) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita interactpoor_dell=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.insdell1 l.insdell2) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

*Table 12;
	codebook regulardummy irregulardummy if sample_act==1 & l.demcheib==1;
	codebook regulardummy irregulardummy if sample_act==1 & l.demcheib==0;
	
	*Regular;
		xi: xtreg regulardummy laggrowthpercapita i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 regulardummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		codebook regulardummy irregulardummy if e(sample);
	
	*Irregular;
		xi: xtreg irregulardummy laggrowthpercapita i.year if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*Multinomial logit;
		generate dummy_mullog=0 if dummy~=.;
		replace dummy_mullog=1 if regulardummy==1;
		replace dummy_mullog=2 if irregulardummy==1;
		xi: mlogit dummy_mullog laggrowthpercapita year i.ccodewb if sample_logit==1, rrr cluster(ccodewb); *Need to restrict to logit sample and use timetrend to achieve convergence;
		test [1]laggrowthpercapita=[2]laggrowthpercapita;
		codebook regulardummy irregulardummy if sample_logit==1;

	*Table 12 tests;
		*Because of the limitations of suest, I do the 2SLS in two separate regressions, and use LSDV instead of xtreg;
			*LPM;
			qui xi: reg regulardummy laggrowthpercapita i.year i.ccodewb if sample_act==1;
			estimates store ch_11_1;
			qui xi: reg irregulardummy laggrowthpercapita i.year i.ccodewb if sample_act==1;
			estimates store ch_11_2;
			qui suest ch_11_1 ch_11_2,cluster(ccodewb);
			test [ch_11_1_mean]laggrowthpercapita =[ch_11_2_mean]laggrowthpercapita;
			prog drop _all;

			*IV;
			qui xi: xtreg laggrowthpercapita L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 L.lnprec L.temp_comb l.temp_comb_cold i.year if sample_act==1, fe;
			qui predict ivch_1table11;
			qui xi: reg regulardummy ivch_1table11 i.year i.ccodewb if sample_act==1;
			qui estimates store ch11_iv1;
			qui xi: reg irregulardummy ivch_1table11 i.year i.ccodewb if sample_act==1;
			qui estimates store ch11_iv2;
			est table ch11_iv1 ch11_iv2,keep(ivch_1table11);
			qui suest ch11_iv1 ch11_iv2,cluster(ccodewb);
			test [ch11_iv1_mean]ivch_1table11 =[ch11_iv2_mean]ivch_1table11; 
			estimates clear;
	
	*Interactions;
		xi: xtivreg2 regulardummy l.demcheib i.year (laggrowthpercapita interactdemlag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1lag l.insdem2lag l.insdem3lag l.insdem4lag l.insdem5lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 irregulardummy l.demcheib i.year (laggrowthpercapita interactdemlag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1lag l.insdem2lag l.insdem3lag l.insdem4lag l.insdem5lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*PWT;
		xi: xtivreg2 regulardummy i.year (lgrgdpch=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 irregulardummy i.year (lgrgdpch=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Instruments individually;
		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

		xi: xtivreg2 irregulardummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1 & l.demcheib==0, first fe fuller(1) cluster(ccodewb) partial(i.year);

*Table 13;
	*Purges (domestic5);
		*Same year;
			xi: xtreg domestic5dummy growthpercapita i.year if sample_act==1 & lnprec~=., fe cluster(ccodewb);
			summ domestic5dummy if e(sample) & domestic5dummy==1;
			xi: xtivreg2 domestic5dummy i.year (growthpercapita=dlogpriceindexinteracted_95 exportpartnergrowthwdiint_95 lnprec temp_comb temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb);

		*Lag;
			xi: xtreg domestic5dummy laggrowthpercapita i.year if sample_act==1, fe cluster(ccodewb);
			summ domestic5dummy if e(sample) & domestic5dummy==1;
			xi: xtivreg2 domestic5dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb);

		*Interaction with democracy;
			xi: xtivreg2 domestic5dummy l.demcheib i.year (laggrowthpercapita interactdemlag=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold l.insdem1lag l.insdem2lag l.insdem3lag l.insdem4lag l.insdem5lag) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

		*Instruments individually;
			xi: xtivreg2 domestic5dummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			xi: xtivreg2 domestic5dummy i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_95) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			xi: xtivreg2 domestic5dummy i.year (laggrowthpercapita=l.lnprec) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			xi: xtivreg2 domestic5dummy i.year (laggrowthpercapita=l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
		*Penn;
			xi: xtivreg2 domestic5dummy i.year (lgrgdpch=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			xi: xtivreg2 domestic5dummy i.year (lgrgdpch=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

******************************************************************************************************
*ADDITIONAL ROBUSTNESS CHECKS MENTIONED IN TEXT;
******************************************************************************************************
	*Party dummies;
		gen party=partystartyear+code;
		xi: xtreg dummy laggrowthpercapita i.year i.party if sample_act==1, fe cluster(ccodewb);
		xi: xtivreg2 dummy i.year i.party (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*Hazard model robustness checks using other functional forms;
		xi: streg laggrowthpercapita i.year i.ccodewb if sample_act==1, dist(exp) vce(cluster ccodewb);
		xi: streg laggrowthpercapita i.year i.ccodewb if sample_act==1, dist(weibull) vce(cluster ccodewb);
		xi: streg laggrowthpercapita i.year i.ccodewb if sample_act==1, dist(gompertz) vce(cluster ccodewb);

	*Reduced form between instruments and protests;
		*Lagged instruments;
		xi: xtreg domestic8 l.ins_cp l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2 i.year if sample_act==1, fe cluster(ccodewb);
		test l.ins_cp l.ins_epg l.ins_pre l.ins_tem1 l.ins_tem2;

		*Current instruments;
		xi: xtreg domestic8 ins_cp ins_epg ins_pre ins_tem1 ins_tem2 i.year if sample_act==1, fe cluster(ccodewb);
		test ins_cp ins_epg ins_pre ins_tem1 ins_tem2;

	*Asymmetry;
		generate positivegrowth=0 if growthpercapita~=.;
		replace positivegrowth=growthpercapita if growthpercapita>0 & growthpercapita~=.;
		generate negativegrowth=0 if growthpercapita~=.;
		replace negativegrowth=growthpercapita if growthpercapita<0 & growthpercapita~=.;
		xi: gen lagpositivegrowth=l.positivegrowth;
		xi: gen lagnegativegrowth=l.negativegrowth;
	
		xi: xtreg dummy lagpositivegrowth lagnegativegrowth i.year if sample_act==1, fe cluster(ccodewb);
		test lagpositivegrowth lagnegativegrowth;

		xi: xtivreg2 dummy i.year (lagpositivegrowth lagnegativegrowth=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		test lagpositivegrowth lagnegativegrowth;

	*Excluding largest countries;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1 & largest20country~=1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Excluding OPEC;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1 & largest20country~=1 & opec~=1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*Excluding commodities for which a country contributed more than 15% of global exports in 1995 from commodity export bundles;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted2 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita=L.dlogpriceindexinteracted2) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			
	*Using 1975 weights;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=l.dlogpriceindexinteracted_75) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummy i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_75) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Using 2000 weights;
		xi: xtivreg2 dummy i.year (laggrowthpercapita=L.exportpartnergrowthwdiint_00) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
			
	*Including additional controls;
		generate inflation_gdpdef100=inflation_gdpdef/100;
		bysort region year: egen regionsum=sum(dummy) if sample_act==1;
		gen flag=1;
		bysort region year: egen countrycount_region=sum(flag) if sample_act==1;
		generate region_share=(regionsum-dummy)/(countrycount_region-1)*100 if sample_act==1;
		sort code year;
		tsset ccodewb year;
		xi: xtivreg2 dummy region_share L2.lngdpp L2.grosssecondcombinedextra L2.old tenure age transitionperiod l.demcheib electionconstructed lelectionconstructed termlimitflag gender prevtimesinoffice entrydummy l.inflation_gdpdef100 l2youth l2urban l2imrinter l2lnpopulation l2exports l.domestic8 firstleaderdummy lconflict lsanctions i.year (laggrowthpercapita=L.dlogpriceindexinteracted_95 L.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Aggregate growth;
		xi: xtivreg2 dummy i.year (laggdpgrowth=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Dependent variable: leaderchangesum;
		xi: xtivreg2 leaderchangesum i.year (laggrowthpercapita=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);

	*Removing cases of sickness;
		xi: xtivreg2 nonsickdummy i.year (laggdpgrowth=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
	
	*Alternative data sources for dependent variable;
		xi: xtivreg2 dummych i.year (laggdpgrowth=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
		xi: xtivreg2 dummybanks i.year (laggdpgrowth=l.dlogpriceindexinteracted_95 l.exportpartnergrowthwdiint_95 l.lnprec l.temp_comb l.temp_comb_cold) if sample_act==1, first fe fuller(1) cluster(ccodewb) partial(i.year);
